==> html2pdf-4.0.5-sources.jar: com/itextpdf/html2pdf/exceptions/TagWorkerInitializationException.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2023 iText Group NV
    Authors: Bruno Lowagie, Paulo Soares, et al.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/

    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.

    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.

    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.

    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.html2pdf.exceptions;

import com.itextpdf.commons.exceptions.ITextException;
import com.itextpdf.commons.utils.MessageFormatUtil;

/**
 * Runtime exception that gets thrown if a tag worker can't be initialized.
 */
public class TagWorkerInitializationException extends ITextException {

    /** Template for the error message in case a tag worker couldn't be instantiated. */
    public static final String REFLECTION_IN_TAG_WORKER_FACTORY_IMPLEMENTATION_FAILED = "Could not "
            + "instantiate TagWorker-class {0} for tag {1}.";

    /**
     * Creates a {@link TagWorkerInitializationException} instance.
     *
     * @param message    the message
     * @param classNames the class names
     * @param tag        the tag
     */
    public TagWorkerInitializationException(String message, String classNames, String tag) {
        super(MessageFormatUtil.format(message,classNames,tag));
    }

    /**
     *  Creates a {@link TagWorkerInitializationException} instance.
     *
     * @param message the message
     * @param classNames the class names
     * @param tag the tag
     * @param cause the cause
     */
    public TagWorkerInitializationException(String message, String classNames, String tag, Throwable cause) {
        super(MessageFormatUtil.format(message,classNames,tag), cause);
    }
}

==> html2pdf-5.0.0-sources.jar: com/itextpdf/html2pdf/exceptions/TagWorkerInitializationException.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2023 Apryse Group NV
    Authors: Apryse Software.

    This program is offered under a commercial and under the AGPL license.
    For commercial licensing, contact us at https://itextpdf.com/sales.  For AGPL licensing, see below.

    AGPL licensing:
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.itextpdf.html2pdf.exceptions;

import com.itextpdf.commons.exceptions.ITextException;
import com.itextpdf.commons.utils.MessageFormatUtil;

/**
 * Runtime exception that gets thrown if a tag worker can't be initialized.
 */
public class TagWorkerInitializationException extends ITextException {

    /** Template for the error message in case a tag worker couldn't be instantiated. */
    public static final String REFLECTION_IN_TAG_WORKER_FACTORY_IMPLEMENTATION_FAILED = "Could not "
            + "instantiate TagWorker-class {0} for tag {1}.";

    /**
     * Creates a {@link TagWorkerInitializationException} instance.
     *
     * @param message    the message
     * @param classNames the class names
     * @param tag        the tag
     */
    public TagWorkerInitializationException(String message, String classNames, String tag) {
        super(MessageFormatUtil.format(message,classNames,tag));
    }

    /**
     *  Creates a {@link TagWorkerInitializationException} instance.
     *
     * @param message the message
     * @param classNames the class names
     * @param tag the tag
     * @param cause the cause
     */
    public TagWorkerInitializationException(String message, String classNames, String tag, Throwable cause) {
        super(MessageFormatUtil.format(message,classNames,tag), cause);
    }
}
